RouteConfig class

类似RouteSettings Router中每个Route 页面 配置信息 之所以自定义,是因为之后可能对 path 的解析可能不同,每个使用者也可能不同 TODO 提供一个 Decoder 给外部调用

Constructors

RouteConfig({String? path, dynamic arguments})

Properties

arguments → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
path String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited